/*************************************************************************************************************************

     Copyright (c) 2015, Analog Devices, Inc.  All rights reserved.

     Redistribution and use in source and binary forms, with or without
     modification, are permitted (subject to the limitations in the
     disclaimer below) provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.

     * Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the
       distribution.

     * Neither the name of Analog Devices, Inc.  nor the names of its
       contributors may be used to endorse or promote products derived
       from this software without specific prior written permission.

     NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE
     GRANTED BY THIS LICENSE.  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT
     HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
     WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
     LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
     CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
     SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
     BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
     WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
     OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
     IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



**************************************************************************************************************************/


/**************************************************************************************************************************

    File name:    sc57x_init.h
    Purpose:      Initialize memory configuration for ADSP-SC571 or ADSP-SC573 EZ-Boards.
    Notes:

**************************************************************************************************************************/

#ifndef SC57X_INIT_H
#define SC57X_INIT_H

#if !defined(__ADSPSC573_FAMILY__)
  #error expected to be built for an ADSP-SC573 family part
#endif

/*
** DMC memory initialization is activated by default below. To disable DMC
** memory define the CONFIG_DMC0 to to 0. This can be done by modifying the
** code below or by defining them in the build settings.
**
** There is one Dynamic Memory Controllers (DMC) on the ADSP-SC573 processor.
** For the ADSP-SC573 EZ-Board it connects to a 2Gb Micron MT41K128M16JT
** chip through the Double Data Rate Synchronous Dynamic Random-Access Memory
** (DDR3 SDRAM) controller. The DDR3 memory controller on the processor and
** the DDR3 memory chip are powered by the on-board 1.5V regulator. Data is
** transferred between the processor and DDR3 on both the rising and falling
** edges of the DDR3 clock. The DDR3 controller on the processor can operate
** up to a maximum clock frequency of 450 MHz
**
** The ADSP-SC571 has no DMC memory.
*/

/* enumerate supported memory types */
#define DMC_NONE                      (0)  /* DMC_NONE must be 0 */
#define Micron_2Gb_DDR3_MT41K128M16JT (1)

/* EZ-Board memory type configuration */
#if defined(__ADSPSC571__)
  #define DMCMEM (DMC_NONE)
#elif defined(__ADSPSC573__)
  #define DMCMEM (Micron_2Gb_DDR3_MT41K128M16JT)
#else
  #error unknown memory type
#endif

#if !defined(CONFIG_DMC0)
  #define CONFIG_DMC0 (DMCMEM)
#endif

#if defined(__ADSPSC570__) || defined(__ADSPSC571__) || defined(__ADSP21571__)
  #if !defined(CONFIG_DMC0)
    /* CONFIG_DMC0 set to 0 for parts that have no DMC */
    #define CONFIG_DMC0 (DMC_NONE)
  #elif CONFIG_DMC0 != DMC_NONE
    #error CONFIG_DMC0 should be 0 for SC570/SC571/21571
  #endif
#endif


/*
 * CGU configuration support is enabled by default and can't be disabled.
 */

#define MHZTOHZ       (1000000u)

/* the ARM core clock is generated from CGU0 */
#define CGU_DEV       (0uL)

/* default power settings */
#define DF_DEFAULT      (0x0u)
#define MSEL_DEFAULT    (0x12u)
#define SYSSEL_DEFAULT  (0x2u)
#define S0SEL_DEFAULT   (0x2u)
#define S1SEL_DEFAULT   (0x2u)
#define CSEL_DEFAULT    (0x1u)
#define DSEL_DEFAULT    (0x1u)

#define CLKIN         (25u  * MHZTOHZ)
#define CORE_MAX      (450u * MHZTOHZ)
#define SYSCLK_MAX    (225u * MHZTOHZ)
#define DMC_CTL_VALUE 		0x00000405
#define DMC_CFG_VALUE 		0x00000522
#define DMC_TR0_VALUE 		0x41711646
#define DMC_TR1_VALUE 		0x40480DB6
#define DMC_TR2_VALUE 		0x00347417
#define DMC_MR0_VALUE		0x00000730
#define DMC_MR1_VALUE 		0x00000006
#define DMC_MR2_VALUE 		0x00000008
#define DMC_PADCTL2_VALUE 	0x0078283C
#define DMC_CPHYCTL_VALUE   0x0000001A
#define DMC0_DATA_CALIB_ADD 0x80000000
#define DMC1_DATA_CALIB_ADD 0xC0000000
/*
 * CONFIG_SMPU controls whether System Memory Protection Unit (SMPU) instances
 * are initialized to disable accesses to :
 *   SMC
 *   PCIe
 *   DMC0 (if !CONFIG_DMC0)
 *   DMC1 (if !CONFIG_DMC1)
 */
#if !defined(CONFIG_SMPU)
  #define CONFIG_SMPU 1 /* done by default */
#endif

/*
 * UNUSED_SPI_FLASH controls whether the 20000018 silicon anomaly SPI flash
 * workaround is included or not. This part of the workaround should most
 * ideally be done in the application code when and if it is known that the
 * SPI flash is not required.
 */
#if !defined(UNUSED_SPI_FLASH)
  /* Not done by default as there is SPI FLASH on EZ-Boards that is used for
   * booting.
   */
  #define UNUSED_SPI_FLASH 0
#endif

#endif /* SC57X_INIT_H */
